@@ -136,12 +136,11 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
             }
 
             pub async fn start_payment_processing(
-                client: Arc<cloud_pubsub::Client>,
                 subscription_name: String,
                 internal_ctx: InternalContext,
                 context_provider: Arc<super::#server_type_name>,
             ) {
-                let subscription = client.subscribe(subscription_name);
+                let subscription = internal_context.pubsub_client.subscribe(subscription_name);
 
                 while subscription.client().is_running() {
                     match subscription.get_messages::<Message>().await {
